pub fn infer_workload_class(method: CheckMethod) -> VerificationWorkloadClassExpand description
Maps a check method onto the scheduler workload class used for budgeting and routing.
pub fn infer_workload_class(method: CheckMethod) -> VerificationWorkloadClassMaps a check method onto the scheduler workload class used for budgeting and routing.