pub fn replay_case(entries: &[LedgerEntry]) -> Result<ReplayedCaseState, String>Expand description
Replays a case ledger in sequence order and reconstructs the terminal aggregate state.
pub fn replay_case(entries: &[LedgerEntry]) -> Result<ReplayedCaseState, String>Replays a case ledger in sequence order and reconstructs the terminal aggregate state.