pub struct CaseRegion {
pub namespace: String,
pub scope_key: Option<ScopeKey>,
pub target_key: String,
pub region_id: Option<RegionId>,
pub region_digest_id: Option<RegionDigestId>,
pub claim_version_id: Option<ClaimVersionId>,
pub as_of_recorded_at: Option<String>,
}Expand description
Scope and location metadata for a verification case target.
Fields
namespace: Stringscope_key: Option<ScopeKey>target_key: Stringregion_id: Option<RegionId>region_digest_id: Option<RegionDigestId>claim_version_id: Option<ClaimVersionId>as_of_recorded_at: Option<String>Trait Implementations
Sourceimpl Clone for CaseRegion
impl Clone for CaseRegion
Sourcefn clone(&self) -> CaseRegion
fn clone(&self) -> CaseRegion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CaseRegion
impl Debug for CaseRegion
Sourceimpl<'de> Deserialize<'de> for CaseRegion
impl<'de> Deserialize<'de> for CaseRegion
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CaseRegion
Sourceimpl JsonSchema for CaseRegion
impl JsonSchema for CaseRegion
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CaseRegion
impl PartialEq for CaseRegion
Sourcefn eq(&self, other: &CaseRegion) -> bool
fn eq(&self, other: &CaseRegion) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CaseRegion
impl Serialize for CaseRegion
impl StructuralPartialEq for CaseRegion