pub struct DegradationMarker {
pub kind: String,
pub reason: String,
pub blocks_promotion: bool,
}Expand description
A marker indicating degraded verification quality and whether it blocks promotion.
Fields
kind: Stringreason: Stringblocks_promotion: boolTrait Implementations
Sourceimpl Clone for DegradationMarker
impl Clone for DegradationMarker
Sourcefn clone(&self) -> DegradationMarker
fn clone(&self) -> DegradationMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DegradationMarker
impl Debug for DegradationMarker
Sourceimpl<'de> Deserialize<'de> for DegradationMarker
impl<'de> Deserialize<'de> for DegradationMarker
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DegradationMarker
Sourceimpl JsonSchema for DegradationMarker
impl JsonSchema for DegradationMarker
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DegradationMarker
impl PartialEq for DegradationMarker
Sourcefn eq(&self, other: &DegradationMarker) -> bool
fn eq(&self, other: &DegradationMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DegradationMarker
impl Serialize for DegradationMarker
impl StructuralPartialEq for DegradationMarker