pub struct LedgerEntry {
pub schema_version: String,
pub entry_id: LedgerEntryId,
pub case_id: VerificationCaseId,
pub sequence_no: u64,
pub recorded_at: String,
pub event: LedgerEvent,
}Expand description
A sequenced, timestamped entry in the verification case ledger.
Fields
schema_version: Stringentry_id: LedgerEntryIdcase_id: VerificationCaseIdsequence_no: u64recorded_at: Stringevent: LedgerEventImplementations
Sourceimpl LedgerEntry
impl LedgerEntry
Sourcepub fn new(
case_id: VerificationCaseId,
sequence_no: u64,
event: LedgerEvent,
) -> Self
pub fn new( case_id: VerificationCaseId, sequence_no: u64, event: LedgerEvent, ) -> Self
Appends a timestamped ledger event for a single verification case.