pub struct ProofProfileV1 {
pub profile_name: String,
pub evidence_admissibility: EvidenceAdmissibilityV1,
pub cheap_checks: Vec<CheapCheckStatusV1>,
pub proof_obligations_remaining: Vec<String>,
pub admissible_evidence: Vec<String>,
}Expand description
Proof profile describing evidence admissibility, cheap-check status, and remaining obligations.
Fields
profile_name: Stringevidence_admissibility: EvidenceAdmissibilityV1cheap_checks: Vec<CheapCheckStatusV1>proof_obligations_remaining: Vec<String>admissible_evidence: Vec<String>Trait Implementations
Sourceimpl Clone for ProofProfileV1
impl Clone for ProofProfileV1
Sourcefn clone(&self) -> ProofProfileV1
fn clone(&self) -> ProofProfileV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProofProfileV1
impl Debug for ProofProfileV1
Sourceimpl<'de> Deserialize<'de> for ProofProfileV1
impl<'de> Deserialize<'de> for ProofProfileV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProofProfileV1
Sourceimpl JsonSchema for ProofProfileV1
impl JsonSchema for ProofProfileV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProofProfileV1
impl PartialEq for ProofProfileV1
Sourcefn eq(&self, other: &ProofProfileV1) -> bool
fn eq(&self, other: &ProofProfileV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProofProfileV1
impl Serialize for ProofProfileV1
impl StructuralPartialEq for ProofProfileV1