pub struct QueueHop {
pub hop_index: u32,
pub from_queue: String,
pub to_queue: String,
pub enqueued_at: String,
pub dequeued_at: Option<String>,
}Expand description
A single queue-to-queue hop in the scheduler routing chain.
Fields
hop_index: u32from_queue: Stringto_queue: Stringenqueued_at: Stringdequeued_at: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for QueueHop
impl<'de> Deserialize<'de> for QueueHop
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for QueueHop
Sourceimpl JsonSchema for QueueHop
impl JsonSchema for QueueHop
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for QueueHop