pub struct ReceiptBudgetContext {
pub budget_kind: Option<String>,
pub max_steps: Option<u32>,
pub time_budget_ms: Option<u64>,
pub cost_budget_units: Option<u64>,
}Expand description
Budget context attached to a control receipt for cost and time tracking.
Fields
budget_kind: Option<String>max_steps: Option<u32>time_budget_ms: Option<u64>cost_budget_units: Option<u64>Trait Implementations
Sourceimpl Clone for ReceiptBudgetContext
impl Clone for ReceiptBudgetContext
Sourcefn clone(&self) -> ReceiptBudgetContext
fn clone(&self) -> ReceiptBudgetContext
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReceiptBudgetContext
impl Debug for ReceiptBudgetContext
Sourceimpl<'de> Deserialize<'de> for ReceiptBudgetContext
impl<'de> Deserialize<'de> for ReceiptBudgetContext
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ReceiptBudgetContext
Sourceimpl JsonSchema for ReceiptBudgetContext
impl JsonSchema for ReceiptBudgetContext
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ReceiptBudgetContext
impl PartialEq for ReceiptBudgetContext
Sourcefn eq(&self, other: &ReceiptBudgetContext) -> bool
fn eq(&self, other: &ReceiptBudgetContext) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ReceiptBudgetContext
impl Serialize for ReceiptBudgetContext
impl StructuralPartialEq for ReceiptBudgetContext