pub struct RegionArtifactTransport {
pub schema_version: String,
pub transport_id: ArtifactTransportId,
pub artifact_kind: RegionArtifactKind,
pub artifact_id: String,
pub artifact_digest: ContentDigest,
pub from_region_id: RegionId,
pub to_region_id: RegionId,
pub from_surface: String,
pub to_surface: String,
pub replay_ref: String,
}Expand description
Transport record for an artifact crossing between compiled verification regions.
Fields
schema_version: Stringtransport_id: ArtifactTransportIdartifact_kind: RegionArtifactKindartifact_id: Stringartifact_digest: ContentDigestfrom_region_id: RegionIdto_region_id: RegionIdfrom_surface: Stringto_surface: Stringreplay_ref: StringImplementations
Sourceimpl RegionArtifactTransport
impl RegionArtifactTransport
Sourcepub fn new(
artifact_kind: RegionArtifactKind,
artifact_id: impl Into<String>,
artifact_bytes: &[u8],
from_region_id: RegionId,
to_region_id: RegionId,
from_surface: impl Into<String>,
to_surface: impl Into<String>,
replay_ref: impl Into<String>,
) -> Self
pub fn new( artifact_kind: RegionArtifactKind, artifact_id: impl Into<String>, artifact_bytes: &[u8], from_region_id: RegionId, to_region_id: RegionId, from_surface: impl Into<String>, to_surface: impl Into<String>, replay_ref: impl Into<String>, ) -> Self
Creates a transport record for an artifact crossing between compiled regions.