pub struct ReplayedCaseState {
pub case: Option<VerificationCase>,
pub plan_count: usize,
pub attempt_count: usize,
pub receipt_count: usize,
pub terminal_disposition: Option<TerminalDisposition>,
}Expand description
Aggregate state reconstructed by replaying a verification case ledger.
Fields
case: Option<VerificationCase>plan_count: usizeattempt_count: usizereceipt_count: usizeterminal_disposition: Option<TerminalDisposition>Trait Implementations
Sourceimpl Clone for ReplayedCaseState
impl Clone for ReplayedCaseState
Sourcefn clone(&self) -> ReplayedCaseState
fn clone(&self) -> ReplayedCaseState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReplayedCaseState
impl Debug for ReplayedCaseState
impl Eq for ReplayedCaseState
Sourceimpl PartialEq for ReplayedCaseState
impl PartialEq for ReplayedCaseState
Sourcefn eq(&self, other: &ReplayedCaseState) -> bool
fn eq(&self, other: &ReplayedCaseState) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ReplayedCaseState