pub struct SchedulerDecision {
pub schema_version: String,
pub case_id: VerificationCaseId,
pub plan_id: CheckPlanId,
pub workload_class: VerificationWorkloadClass,
pub cheapest_adequate: bool,
pub queue_hops: Vec<QueueHop>,
pub budget_lineage: BudgetLineage,
pub exactness_budget: Option<ExactnessBudgetV1>,
pub degradation_markers: Vec<DegradationMarker>,
pub promotion_blocked: bool,
}Expand description
Scheduler decision record preserving budget, degradation, and routing lineage for a plan.
Fields
schema_version: Stringcase_id: VerificationCaseIdplan_id: CheckPlanIdworkload_class: VerificationWorkloadClasscheapest_adequate: boolqueue_hops: Vec<QueueHop>budget_lineage: BudgetLineageexactness_budget: Option<ExactnessBudgetV1>degradation_markers: Vec<DegradationMarker>promotion_blocked: boolTrait Implementations
Sourceimpl Clone for SchedulerDecision
impl Clone for SchedulerDecision
Sourcefn clone(&self) -> SchedulerDecision
fn clone(&self) -> SchedulerDecision
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SchedulerDecision
impl Debug for SchedulerDecision
Sourceimpl<'de> Deserialize<'de> for SchedulerDecision
impl<'de> Deserialize<'de> for SchedulerDecision
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SchedulerDecision
Sourceimpl JsonSchema for SchedulerDecision
impl JsonSchema for SchedulerDecision
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SchedulerDecision
impl PartialEq for SchedulerDecision
Sourcefn eq(&self, other: &SchedulerDecision) -> bool
fn eq(&self, other: &SchedulerDecision) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SchedulerDecision
impl Serialize for SchedulerDecision
impl StructuralPartialEq for SchedulerDecision