pub struct ToolExposureDecisionV1 {
pub tool_name: String,
pub exposed: bool,
pub reason: String,
}Expand description
Explicit per-turn tool exposure, including the empty set.
Fields
tool_name: Stringexposed: boolreason: StringTrait Implementations
Sourceimpl Clone for ToolExposureDecisionV1
impl Clone for ToolExposureDecisionV1
Sourcefn clone(&self) -> ToolExposureDecisionV1
fn clone(&self) -> ToolExposureDecisionV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolExposureDecisionV1
impl Debug for ToolExposureDecisionV1
Sourceimpl<'de> Deserialize<'de> for ToolExposureDecisionV1
impl<'de> Deserialize<'de> for ToolExposureDecisionV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ToolExposureDecisionV1
Sourceimpl From<ToolExposureDecision> for ToolExposureDecisionV1
impl From<ToolExposureDecision> for ToolExposureDecisionV1
Sourcefn from(value: ToolExposureDecision) -> Self
fn from(value: ToolExposureDecision) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for ToolExposureDecisionV1
impl JsonSchema for ToolExposureDecisionV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ToolExposureDecisionV1
impl PartialEq for ToolExposureDecisionV1
Sourcefn eq(&self, other: &ToolExposureDecisionV1) -> bool
fn eq(&self, other: &ToolExposureDecisionV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ToolExposureDecisionV1
impl Serialize for ToolExposureDecisionV1
impl StructuralPartialEq for ToolExposureDecisionV1