pub struct VerificationAttempt {
pub schema_version: String,
pub case_id: VerificationCaseId,
pub plan_id: CheckPlanId,
pub attempt_id: AttemptId,
pub trial_id: Option<TrialId>,
pub state: VerificationAttemptState,
pub advisory_only: bool,
pub degraded: bool,
pub started_at: String,
pub finished_at: String,
pub outcome_signature: Option<String>,
}Expand description
A single execution attempt within a verification case and plan.
Fields
schema_version: Stringcase_id: VerificationCaseIdplan_id: CheckPlanIdattempt_id: AttemptIdtrial_id: Option<TrialId>state: VerificationAttemptStateadvisory_only: booldegraded: boolstarted_at: Stringfinished_at: Stringoutcome_signature: Option<String>Implementations
Sourceimpl VerificationAttempt
impl VerificationAttempt
Sourcepub fn completed(
case_id: VerificationCaseId,
plan_id: CheckPlanId,
attempt_id: AttemptId,
trial_id: Option<TrialId>,
state: VerificationAttemptState,
advisory_only: bool,
degraded: bool,
started_at: impl Into<String>,
finished_at: impl Into<String>,
outcome_signature: Option<String>,
) -> Self
pub fn completed( case_id: VerificationCaseId, plan_id: CheckPlanId, attempt_id: AttemptId, trial_id: Option<TrialId>, state: VerificationAttemptState, advisory_only: bool, degraded: bool, started_at: impl Into<String>, finished_at: impl Into<String>, outcome_signature: Option<String>, ) -> Self
Records a completed verification attempt and its terminal execution metadata.