pub struct DecisionTraceV1 {Show 13 fields
pub schema_version: String,
pub decision_trace_id: DecisionTraceId,
pub triggering_artifact_refs: Vec<String>,
pub intervention_id: InterventionId,
pub counterfactual_slice_id: CounterfactualSliceId,
pub refuters_satisfied: Vec<String>,
pub refuters_failed: Vec<String>,
pub refuters_skipped: Vec<String>,
pub exactness_spend: ExactnessSpendV1,
pub policy_basis: Vec<String>,
pub selected_decision: SelectedDecisionV1,
pub rollback_prerequisites: Vec<String>,
pub cheap_next_checks: Vec<String>,
}Expand description
Trace record capturing the full decision path from triggering artifacts through refuter outcomes to the selected promotion or rollback decision.
Fields
schema_version: Stringdecision_trace_id: DecisionTraceIdtriggering_artifact_refs: Vec<String>intervention_id: InterventionIdcounterfactual_slice_id: CounterfactualSliceIdrefuters_satisfied: Vec<String>refuters_failed: Vec<String>refuters_skipped: Vec<String>exactness_spend: ExactnessSpendV1policy_basis: Vec<String>selected_decision: SelectedDecisionV1rollback_prerequisites: Vec<String>cheap_next_checks: Vec<String>Implementations