pub struct EffectBlockReceiptV1 {
pub schema_version: String,
pub effect_block_receipt_id: EffectBlockReceiptId,
pub effect_review_case_id: EffectReviewCaseId,
pub citation: V25CitationContext,
pub obligation_refs: V25ControlObligationRefs,
pub citation_status: ConstitutionalContextStatus,
pub obligation_refs_status: ConstitutionalContextStatus,
pub block_reason: EffectBlockReasonV1,
pub generated_at: String,
}Expand description
Receipt emitted when an effect action is blocked by policy or budget constraints.
Fields
schema_version: Stringeffect_block_receipt_id: EffectBlockReceiptIdeffect_review_case_id: EffectReviewCaseIdcitation: V25CitationContextobligation_refs: V25ControlObligationRefscitation_status: ConstitutionalContextStatusobligation_refs_status: ConstitutionalContextStatusblock_reason: EffectBlockReasonV1generated_at: StringImplementations
Sourceimpl EffectBlockReceiptV1
impl EffectBlockReceiptV1
Sourcepub fn new(
effect_review_case_id: EffectReviewCaseId,
citation: V25CitationContext,
obligation_refs: V25ControlObligationRefs,
block_reason: EffectBlockReasonV1,
generated_at: impl Into<String>,
) -> Result<Self, String>
pub fn new( effect_review_case_id: EffectReviewCaseId, citation: V25CitationContext, obligation_refs: V25ControlObligationRefs, block_reason: EffectBlockReasonV1, generated_at: impl Into<String>, ) -> Result<Self, String>
Creates an effect block receipt with computed constitutional context status.